package info.mathhub.uloapi.html;

import info.mathhub.uloapi.query.Query;
import info.mathhub.uloapi.query.Statistics;
import info.mathhub.uloapi.query.Timer;
import org.eclipse.rdf4j.model.Statement;
import spark.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * This class contains all routes of our application.
 */
public class Routes {
    private Routes() {};

    public static final TemplateViewRoute index = (Request request, Response response) -> {
        return new ModelAndView(null, "index.flt");
    };

    public static final TemplateViewRoute statistics = (Request request, Response response) -> {
        final Query query = Query.getSingleton();
        final Statistics statistics = query.getStatistics();

        final Map<String, Object> model = new HashMap<>();
        model.put("statistics_num_triplets", statistics.numTriplets);
        model.put("statistics_is_writeable", Boolean.toString(statistics.isWriteable));
        model.put("statistics_data_dir", statistics.dataDir);

        return new ModelAndView(model, "statistics.flt");
    };

    public static final TemplateViewRoute queries = (Request request, Response response) -> {
        final Query query = Query.getSingleton();

        final Timer inductiveStatementsTimer = new Timer();
        final List<Statement> inductiveStatements = query.getInductiveStatements();
        final long inductiveStatementsDuration = inductiveStatementsTimer.elapsedMs();

        final Map<String, Object> model = new HashMap<>();
        model.put("inductive_statements", inductiveStatements);
        model.put("inductive_statements_duration", inductiveStatementsDuration);

        return new ModelAndView(model, "queries.flt");
    };
}
