package info.mathhub.uloapi.rest;

import com.google.gson.Gson;
import org.eclipse.jetty.http.HttpStatus;
import spark.Request;
import spark.Response;
import spark.Route;

public class Errors {
    private Errors() {};

    private final static Gson gson = new Gson();

    private static class JsonError {
        final int status;
        final String message;

        JsonError(int status) {
            this.status = status;
            this.message = HttpStatus.getMessage(status);
        }
    }

    public static final Route notFound = (Request request, Response response) -> {
        return createError(HttpStatus.NOT_FOUND_404).handle(request, response);
    };

    public static final Route notAcceptable = (Request request, Response response) -> {
        return createError(HttpStatus.NOT_ACCEPTABLE_406).handle(request, response);
    };

    public static final Route notImplemented = (Request request, Response response) -> {
        return createError(HttpStatus.NOT_IMPLEMENTED_501).handle(request, response);
    };

    private static Route createError(int status) {
        return (Request request, Response response) -> {
            final JsonError obj = new JsonError(status);
            return Errors.gson.toJson(obj);
        };
    }
}
